<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="14"/>
        <source>General settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="35"/>
        <source>General OpenSCAD Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="43"/>
        <source>OpenSCAD executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="56"/>
        <source>The path to the OpenSCAD executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="74"/>
        <source>OpenSCAD import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="82"/>
        <source>Print debug information in the Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="99"/>
        <source>If this is checked, Features will claim their children in the tree view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="102"/>
        <source>Use ViewProvider in Tree View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="119"/>
        <source>If this is checked, Multmatrix Object will be Parametric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="122"/>
        <source>Use Multmatrix Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="139"/>
        <location filename="../ui/openscadprefs-base.ui" line="162"/>
        <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="142"/>
        <source>Maximum number of faces for polygons (fn)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="182"/>
        <source>Send to OpenSCAD via:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="195"/>
        <source>The transfer mechanism for getting data to and from OpenSCAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="205"/>
        <source>Standard temp directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="210"/>
        <source>User-specified directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="215"/>
        <source>stdout pipe (requires OpenSCAD &gt;= 2021.1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="227"/>
        <source>Transfer directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="240"/>
        <source>The path to the directory for transferring files to and from OpenSCAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="258"/>
        <source>OpenSCAD export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="266"/>
        <source>Maximum fragment size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="289"/>
        <source>angle (fa)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="385"/>
        <source>Convexity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="286"/>
        <location filename="../ui/openscadprefs-base.ui" line="296"/>
        <source>Minimum angle for a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="328"/>
        <location filename="../ui/openscadprefs-base.ui" line="353"/>
        <source>Minimum size of a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="331"/>
        <source>size (fs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="359"/>
        <source>mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="422"/>
        <source>Mesh fallback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="442"/>
        <location filename="../ui/openscadprefs-base.ui" line="459"/>
        <source>Deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="445"/>
        <source>deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/openscadprefs-base.ui" line="452"/>
        <source>Triangulation settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD</name>
    <message>
        <location filename="../../InitGui.py" line="130"/>
        <source>It looks like you may be using a Snap version of OpenSCAD.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../InitGui.py" line="135"/>
        <location filename="../../InitGui.py" line="148"/>
        <source>If OpenSCAD execution fails to load the temporary file, use FreeCAD&apos;s OpenSCAD Workbench Preferences to change the transfer mechanism.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../InitGui.py" line="143"/>
        <source>It looks like you may be using a sandboxed version of FreeCAD.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="92"/>
        <source>Unable to explode %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="139"/>
        <source>Convert Edges to Faces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="301"/>
        <source>Please select 3 objects first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="334"/>
        <location filename="../../OpenSCADCommands.py" line="365"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="369"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="366"/>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="367"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="335"/>
        <location filename="../../OpenSCADCommands.py" line="368"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="336"/>
        <source>Clear code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="337"/>
        <source>Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="338"/>
        <source>Save...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="339"/>
        <location filename="../../OpenSCADCommands.py" line="370"/>
        <source>as Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="352"/>
        <location filename="../../OpenSCADCommands.py" line="371"/>
        <source>Add OpenSCAD Element</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="428"/>
        <source>Open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="430"/>
        <location filename="../../OpenSCADCommands.py" line="444"/>
        <source>OpenSCAD Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="442"/>
        <source>Save file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="456"/>
        <location filename="../../OpenSCADCommands.py" line="485"/>
        <source>Perform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="482"/>
        <location filename="../../OpenSCADCommands.py" line="486"/>
        <source>Mesh Boolean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="487"/>
        <source>Minkowski sum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADUtils.py" line="654"/>
        <source>OpenSCAD file contains both 2D and 3D shapes. That is not supported in this importer, all shapes must have the same dimensionality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADUtils.py" line="665"/>
        <source>Error: either all shapes must be 2D or all shapes must be 3D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../importCSG.py" line="550"/>
        <location filename="../../importCSG.py" line="1432"/>
        <source>Unsupported Function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../importCSG.py" line="550"/>
        <location filename="../../importCSG.py" line="1432"/>
        <source>Press OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="100"/>
        <source>Explode Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="103"/>
        <source>Remove fusion, apply placement to children, and color randomly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="116"/>
        <source>Color Shapes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="119"/>
        <source>Color Shapes by validity and type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="136"/>
        <source>Convert Edges To Faces</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="156"/>
        <source>Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="159"/>
        <source>Create Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="186"/>
        <source>Mirror Mesh Feature...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="189"/>
        <source>Create Mirror Mesh Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="215"/>
        <source>Scale Mesh Feature...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="219"/>
        <source>Create Scale Mesh Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="245"/>
        <source>Resize Mesh Feature...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="249"/>
        <source>Create Resize Mesh Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="266"/>
        <source>Increase Tolerance Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="269"/>
        <source>Create Feature that allows increasing the tolerance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="283"/>
        <source>Expand Placements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="286"/>
        <source>Expand all placements downwards in the Tree view</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="304"/>
        <source>Replace Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="307"/>
        <source>Replace an object in the Tree view. Please select old, new, and parent object</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="317"/>
        <source>Remove Objects and their Children</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="320"/>
        <source>Removes the selected objects and all children that are not referenced from other objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="530"/>
        <source>Add OpenSCAD Element...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="534"/>
        <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="545"/>
        <source>Mesh Boolean...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="549"/>
        <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Hull</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="566"/>
        <source>Hull</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="569"/>
        <source>Use OpenSCAD to create a hull</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="../../InitGui.py" line="152"/>
        <source>OpenSCAD Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../InitGui.py" line="156"/>
        <source>Frequently-used Part WB tools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Minkowski</name>
    <message>
        <location filename="../../OpenSCADCommands.py" line="586"/>
        <source>Minkowski sum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OpenSCADCommands.py" line="589"/>
        <source>Use OpenSCAD to create a Minkowski sum</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
